/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState } from 'react';
//imports material ui components
import { TextField, Button } from '@material-ui/core';
import CircularProgress from '@material-ui/core/CircularProgress';
import SaveIcon from '@material-ui/icons/Save';
//imports local files
import SnackBar from '../../../../Components/SnackbarComponent';
//imports services 
import { Edit } from '../../../Services'; 
import {EditFilter , Url} from '../../../Filters';

const NoteVarInputs = (props) => {
    const [isLoading, setIsLoading] = useState(false);
    const id = props.editInfo.id
    const [name, setName] = useState(props.editInfo.name)
    const [code, setCode] = useState(props.editInfo.code)
    const [weight, setWeight] = useState(props.editInfo.weight)

    const [errorInName, setErrorInName] = useState({
        error: false,
        message: ''
    })

    const [errorInCode, setErrorInCode] = useState({
        error: false,
        message: ''
    })

    const [errorInWeight, setErrorInWeight] = useState({
        error: false,
        message: ''
    })

    const [snackInfo, setSnackInfo] = useState({
        message: '',
        icon: '',
        open: false,
        color: '',
    })

    const NameHandler = (e) => {
        if (errorInName.error) {
            setErrorInName({
                error: false,
                message: ''
            })
        }
        setName(e.target.value)
    }

    const CodeHandler = (e) => {
        if (errorInCode.error) {
            setErrorInCode({
                error: false,
                message: ''
            })
        }
        setCode(e.target.value)
    }

    const WeightHandler = (e) => {
        if (errorInWeight.error) {
            setErrorInWeight({
                error: false,
                message: ''
            })
        }
        setWeight(e.target.value)
    }

    //Verify if the string is empty
    const isEmpty = (text) => {
        return text.length === 0 ? true : false;
    }

    // Fields
    const fields = [
        {
            label: 'ID',
            value: id,
            default: true,
            type: 'text'
        },
        {
            label: 'Nome',
            value: name,
            error: errorInName.error,
            errorMessage: errorInName.message,
            onChange: (event) => NameHandler(event),
            default: false,
            type: 'text',
        },
        {
            label: 'Código',
            value: code,
            error: errorInCode.error,
            errorMessage: errorInCode.message,
            onChange: (event) => CodeHandler(event),
            default: false,
            type: 'text'
        },
        {
            label: 'Peso',
            value: weight,
            error: errorInWeight.error,
            errorMessage: errorInWeight.message,
            onChange: (event) => WeightHandler(event),
            default: false,
            type: 'number',
        }
    ]

    // Handle snack infos
    const HandleSnack = (message, state, icon, color) => {
        setSnackInfo({
            message: message,
            icon: icon,
            open: state,
            color: color
        })
    }

    const onSubmit = async () => {
        setIsLoading(true)
        if (!isEmpty(name) && !isEmpty(code) && !isEmpty(weight)) {
            const api = EditFilter('scores' , id)
            const body = {
                "score": {
                    'name': name,
                    'code': code, 
                    'weight' : weight
                }
            } 
            Edit(api , body).then(res => {
                if(res) {
                    HandleSnack('A variável de nota foi alterada com sucesso', true, 'success', '#228B22')
                } else {
                    HandleSnack('Ocorreu algum erro', true, 'warning', '#FA8072')
                } 
                setIsLoading(false)
            })
        }
        else {
            HandleSnack('Você precisa preencher algumas informações obrigatórias', true, 'warning', '#FFC125')
            if (isEmpty(name)) {
                setErrorInName({
                    error: true,
                    message: 'Este campo precisa ser preenchido'
                })
            }
            if (isEmpty(code)) {
                setErrorInCode({
                    error: true,
                    message: 'Este campo precisa ser preenchido'
                })
            }
            if (isEmpty(weight)) {
                setErrorInWeight({
                    error: true,
                    message: 'Este campo precisa ser preenchido'
                })
            }
            setIsLoading(false)
        }
    }

    return (
        <div>
            <SnackBar
                severity={snackInfo.icon}
                text={snackInfo.message}
                snackbarOpen={snackInfo.open}
                color={snackInfo.color}
                handleClose={() => setSnackInfo({
                    message: '',
                    icon: '',
                    open: false,
                    color: ''
                })}
            />
            <form style={{ display: 'flex', flexDirection: 'column' }}>
                {fields.map((field, index) => (
                    <TextField
                        key={index}
                        error={field.error}
                        disabled={field.default}
                        helperText={field.error ? field.errorMessage : ''}
                        style={{ width: '250px', marginBottom: '1em' }}
                        label={field.label}
                        value={field.value}
                        onChange={field.onChange}
                        type={field.type}
                        multiline={true}
                    />
                ))}
            </form>
            <div>
                <Button
                    onClick={() => {
                        onSubmit();
                        setTimeout(function(){props.UpdateList(Url('scores' , '' , '0' , 'DESC'))}, 3000) 
                    }}
                    variant="contained"
                    color="primary"
                    disabled={isLoading}
                    startIcon={isLoading ? null : <SaveIcon />}
                >
                    {
                        isLoading ? <CircularProgress size={24} /> : 'Salvar'
                    }
                </Button>
            </div>
        </div>
    )
}

export default NoteVarInputs;